@@ -238,32 +238,60 @@ STATIC microdesc_t *dirvote_create_microdescriptor(const routerinfo_t *ri,
 /** The recommended relay protocols for this authority's votes.
  * Recommending a new protocol causes old tor versions to log a warning.
  */
-#define DIRVOTE_RECOMMEND_RELAY_PROTO \
-  "Cons=1-2 Desc=1-2 DirCache=2 HSDir=2 HSIntro=4 HSRend=2 " \
-  "Link=5 LinkAuth=3 Microdesc=1-2 Relay=2"
+#define DIRVOTE_RECOMMEND_RELAY_PROTO           \
+  "Cons=2 "                                     \
+  "Desc=2 "                                     \
+  "DirCache=2 "                                 \
+  "HSDir=2 "                                    \
+  "HSIntro=4 "                                  \
+  "HSRend=2 "                                   \
+  "Link=4-5 "                                   \
+  "LinkAuth=3 "                                 \
+  "Microdesc=2 "                                \
+  "Relay=2"
+
 /** The recommended client protocols for this authority's votes.
  * Recommending a new protocol causes old tor versions to log a warning.
  */
-#define DIRVOTE_RECOMMEND_CLIENT_PROTO \
-  "Cons=1-2 Desc=1-2 DirCache=2 HSDir=2 HSIntro=4 HSRend=2 " \
-  "Link=5 LinkAuth=3 Microdesc=1-2 Relay=2"
+#define DIRVOTE_RECOMMEND_CLIENT_PROTO          \
+  "Cons=2 "                                     \
+  "Desc=2 "                                     \
+  "DirCache=2 "                                 \
+  "HSDir=2 "                                    \
+  "HSIntro=4 "                                  \
+  "HSRend=2 "                                   \
+  "Link=4-5 "                                   \
+  "Microdesc=2 "                                \
+  "Relay=2"
 
 /** The required relay protocols for this authority's votes.
  * WARNING: Requiring a new protocol causes old tor versions to shut down.
  *          Requiring the wrong protocols can break the tor network.
  * See Proposal 303: When and how to remove support for protocol versions.
  */
-#define DIRVOTE_REQUIRE_RELAY_PROTO \
-  "Cons=1 Desc=1 DirCache=1 HSDir=1 HSIntro=3 HSRend=1 " \
-  "Link=3-4 Microdesc=1 Relay=1-2"
+#define DIRVOTE_REQUIRE_RELAY_PROTO             \
+  "Cons=2 "                                     \
+  "Desc=2 "                                     \
+  "DirCache=2 "                                 \
+  "HSDir=2 "                                    \
+  "HSIntro=4 "                                  \
+  "HSRend=2 "                                   \
+  "Link=4-5 "                                   \
+  "LinkAuth=3 "                                 \
+  "Microdesc=2 "                                \
+  "Relay=2"
+
 /** The required relay protocols for this authority's votes.
  * WARNING: Requiring a new protocol causes old tor versions to shut down.
  *          Requiring the wrong protocols can break the tor network.
  * See Proposal 303: When and how to remove support for protocol versions.
  */
-#define DIRVOTE_REQUIRE_CLIENT_PROTO \
-  "Cons=1-2 Desc=1-2 DirCache=1 HSDir=1 HSIntro=3 HSRend=1 " \
-  "Link=4 Microdesc=1-2 Relay=2"
+#define DIRVOTE_REQUIRE_CLIENT_PROTO            \
+  "Cons=2 "                                     \
+  "Desc=2 "                                     \
+  "Link=4 "                                     \
+  "Microdesc=2 "                                \
+  "Relay=2"
 
 #endif /* defined(DIRVOTE_PRIVATE) */
 
